#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const update_check_1 = __importDefault(require("update-check"));
const package_json_1 = __importDefault(require("../package.json"));
const commander_1 = __importDefault(require("commander"));
const get_pkg_manager_1 = require("./helpers/get-pkg-manager");
const init_1 = require("./init");
const package_1 = require("./sandbox/package");
const handleSigTerm = () => process.exit(0);
process.on('SIGINT', handleSigTerm);
process.on('SIGTERM', handleSigTerm);
let verbose = false;
const program = new commander_1.default.Command(package_json_1.default.name)
    .version(package_json_1.default.version)
    .option('-v, --verbose', 'Enable verbose output');
const options = program.opts();
verbose = options.verbose ? true : false;
if (verbose) {
    console.log('Verbose mode enabled.');
    console.log();
}
const packageManager = (0, get_pkg_manager_1.getPkgManager)();
function notifyUpdate() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            console.log('Running Mirrorful version: ' + chalk_1.default.green(package_json_1.default.version));
            const res = yield (0, update_check_1.default)(package_json_1.default);
            if (res === null || res === void 0 ? void 0 : res.latest) {
                const updateMessage = packageManager === 'yarn'
                    ? 'yarn add mirrorful@latest'
                    : packageManager === 'pnpm'
                        ? 'pnpm up mirrorful@latest'
                        : 'npm i mirrorful@latest';
                console.log(chalk_1.default.yellow.bold('A new version of `mirrorful` is available!') +
                    '\n' +
                    'You can update by running: ' +
                    chalk_1.default.cyan(updateMessage) +
                    '\n');
            }
        }
        catch (e) {
            // ignore error
            if (verbose) {
                console.log(chalk_1.default.yellow.bold('WARNING: could not check for update '), e);
            }
        }
    });
}
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            console.log(`Starting Mirrorful in ${chalk_1.default.green(process.cwd())}.`);
            console.log();
            yield (0, init_1.init)({
                appPath: process.cwd(),
                packageManager,
                verbose,
            });
        }
        catch (reason) {
            console.error(reason);
        }
    });
}
program
    .command('package')
    .description('Packages your component library')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    console.log('Running package...');
    yield (0, package_1.packageLibrary)();
}));
program
    .command('editor', { isDefault: true })
    .description('Runs the Mirrorful Editor')
    .action(() => {
    notifyUpdate()
        .then(main)
        .catch((reason) => __awaiter(void 0, void 0, void 0, function* () {
        console.log();
        console.log('Aborting.');
        if (reason.command) {
            console.log(`  ${chalk_1.default.cyan(reason.command)} has failed.`);
        }
        else {
            console.log(chalk_1.default.red('Unexpected error.Please report it as a bug on our repo: https://github.com/Mirrorful/mirrorful') + '\n', reason);
        }
        console.log();
        yield notifyUpdate();
        process.exit(1);
    }));
});
program.parse(process.argv);
