"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = void 0;
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const is_writeable_1 = require("./helpers/is-writeable");
const make_dir_1 = require("./helpers/make-dir");
const cross_spawn_1 = __importDefault(require("cross-spawn"));
const find_node_modules_1 = require("./helpers/find-node-modules");
const fs_1 = __importDefault(require("fs"));
const openBrowser_1 = __importDefault(require("./helpers/openBrowser"));
const patch_next_js_file_for_pnpm_1 = require("./helpers/patch-next-js-file-for-pnpm");
function init({ appPath, packageManager, verbose, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const root = path_1.default.resolve(appPath);
        if (!(yield (0, is_writeable_1.isWriteable)(path_1.default.dirname(root)))) {
            console.error('The application path is not writable, please check folder permissions and try again.');
            console.error('It is likely you do not have write permissions for this folder.');
            process.exit(1);
        }
        yield (0, make_dir_1.makeDir)('.mirrorful');
        const port = 5050; // don't hard code this
        // await openBrowser({ url: 'http://localhost', port })
        if (verbose) {
            console.log('Current directory:', process.cwd());
        }
        // find where the node_modules folder is
        const nodeModulesPath = yield (0, find_node_modules_1.findNodeModulesMirrorfulPath)();
        let isUsingNextJs = false;
        if (process.env.NODE_ENV === 'development') {
            // just run the editor in its own directory
            process.chdir(`editor`);
        }
        else {
            if (nodeModulesPath) {
                try {
                    yield fs_1.default.promises.access(`next.config.js`, fs_1.default.constants.F_OK);
                    isUsingNextJs = true;
                }
                catch (e) {
                    if (verbose) {
                        console.log('Non-mirrorful next.config.js not found: ', e);
                    }
                    isUsingNextJs = false;
                }
                process.chdir(`${nodeModulesPath}/editor`);
                if (verbose) {
                    console.log('New working directory:', process.cwd());
                }
            }
        }
        let command = 'start';
        if (isUsingNextJs) {
            if (verbose) {
                console.log('NextJS app detected.');
            }
            command = 'next-start'; // this is a custom command that uses the .bin/next
        }
        if (process.env.NODE_ENV === 'development') {
            command = 'dev';
        }
        const useYarn = packageManager === 'yarn';
        console.log('Inside your project, you can run:');
        console.log(chalk_1.default.cyan(`  ${useYarn ? 'yarn run ' : 'npx '}mirrorful`));
        console.log('to start the visual editor at any time.');
        console.log();
        if (packageManager === 'pnpm') {
            yield (0, patch_next_js_file_for_pnpm_1.patchNextJsFileForPnpm)({
                rootNodeModulesFile: nodeModulesPath !== null && nodeModulesPath !== void 0 ? nodeModulesPath : '',
            });
        }
        try {
            const outputMode = verbose ? 'inherit' : 'ignore';
            const output = (0, cross_spawn_1.default)('yarn', ['run', command, '-p', port.toString()], {
                // if you use pipe, then control + c throws an empty error
                stdio: [outputMode, outputMode, 'inherit'],
            });
            if (output.stderr) {
                console.log(chalk_1.default.red('Unexpected error. Please report it as a bug on our repo: https://github.com/Mirrorful/mirrorful') + '\n');
                console.log();
                console.log(`Stderr: ${output.stderr}`);
            }
        }
        catch (error) {
            if (error instanceof Error) {
                console.log();
                console.log(`Error: ${error.message}`);
            }
        }
        yield (0, openBrowser_1.default)({ url: 'http://localhost', port });
    });
}
exports.init = init;
